/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#include "DrawingArea.h"

#if PLATFORM(MAC)
#include "ColorSpaceData.h"
#endif
#include "DrawingAreaMessages.h"
#include "HandleMessage.h"
#include "MessageDecoder.h"
#include "WebCoreArgumentCoders.h"
#if PLATFORM(MAC)
#include <WebCore/FloatPoint.h>
#endif
#if PLATFORM(MAC)
#include <WebCore/FloatRect.h>
#endif
#include <WebCore/IntSize.h>

namespace WebKit {

void DrawingArea::didReceiveDrawingAreaMessage(IPC::Connection*, IPC::MessageDecoder& decoder)
{
    if (decoder.messageName() == Messages::DrawingArea::UpdateBackingStoreState::name()) {
        IPC::handleMessage<Messages::DrawingArea::UpdateBackingStoreState>(decoder, this, &DrawingArea::updateBackingStoreState);
        return;
    }
    if (decoder.messageName() == Messages::DrawingArea::DidUpdate::name()) {
        IPC::handleMessage<Messages::DrawingArea::DidUpdate>(decoder, this, &DrawingArea::didUpdate);
        return;
    }
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::DrawingArea::UpdateGeometry::name()) {
        IPC::handleMessage<Messages::DrawingArea::UpdateGeometry>(decoder, this, &DrawingArea::updateGeometry);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::DrawingArea::SetDeviceScaleFactor::name()) {
        IPC::handleMessage<Messages::DrawingArea::SetDeviceScaleFactor>(decoder, this, &DrawingArea::setDeviceScaleFactor);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::DrawingArea::SetColorSpace::name()) {
        IPC::handleMessage<Messages::DrawingArea::SetColorSpace>(decoder, this, &DrawingArea::setColorSpace);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::DrawingArea::SetExposedRect::name()) {
        IPC::handleMessage<Messages::DrawingArea::SetExposedRect>(decoder, this, &DrawingArea::setExposedRect);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::DrawingArea::SetCustomFixedPositionRect::name()) {
        IPC::handleMessage<Messages::DrawingArea::SetCustomFixedPositionRect>(decoder, this, &DrawingArea::setCustomFixedPositionRect);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::DrawingArea::AdjustTransientZoom::name()) {
        IPC::handleMessage<Messages::DrawingArea::AdjustTransientZoom>(decoder, this, &DrawingArea::adjustTransientZoom);
        return;
    }
#endif
#if PLATFORM(MAC)
    if (decoder.messageName() == Messages::DrawingArea::CommitTransientZoom::name()) {
        IPC::handleMessage<Messages::DrawingArea::CommitTransientZoom>(decoder, this, &DrawingArea::commitTransientZoom);
        return;
    }
#endif
    ASSERT_NOT_REACHED();
}

} // namespace WebKit
