/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#include "WebOriginDataManager.h"

#include "HandleMessage.h"
#include "MessageDecoder.h"
#include "SecurityOriginData.h"
#include "WebOriginDataManagerMessages.h"

namespace WebKit {

void WebOriginDataManager::didReceiveMessage(IPC::Connection* connection, IPC::MessageDecoder& decoder)
{
    if (decoder.messageName() == Messages::WebOriginDataManager::GetOrigins::name()) {
        IPC::handleMessage<Messages::WebOriginDataManager::GetOrigins>(decoder, this, &WebOriginDataManager::getOrigins);
        return;
    }
    if (decoder.messageName() == Messages::WebOriginDataManager::DeleteEntriesForOrigin::name()) {
        IPC::handleMessage<Messages::WebOriginDataManager::DeleteEntriesForOrigin>(decoder, this, &WebOriginDataManager::deleteEntriesForOrigin);
        return;
    }
    if (decoder.messageName() == Messages::WebOriginDataManager::DeleteAllEntries::name()) {
        IPC::handleMessage<Messages::WebOriginDataManager::DeleteAllEntries>(decoder, this, &WebOriginDataManager::deleteAllEntries);
        return;
    }
    if (decoder.messageName() == Messages::WebOriginDataManager::StartObservingChanges::name()) {
        IPC::handleMessage<Messages::WebOriginDataManager::StartObservingChanges>(decoder, this, &WebOriginDataManager::startObservingChanges);
        return;
    }
    if (decoder.messageName() == Messages::WebOriginDataManager::StopObservingChanges::name()) {
        IPC::handleMessage<Messages::WebOriginDataManager::StopObservingChanges>(decoder, this, &WebOriginDataManager::stopObservingChanges);
        return;
    }
    UNUSED_PARAM(connection);
    ASSERT_NOT_REACHED();
}

} // namespace WebKit
