/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebOriginDataManagerMessages_h
#define WebOriginDataManagerMessages_h

#include "Arguments.h"
#include "MessageEncoder.h"
#include "StringReference.h"

namespace WebKit {
    struct SecurityOriginData;
}

namespace Messages {
namespace WebOriginDataManager {

static inline IPC::StringReference messageReceiverName()
{
    return IPC::StringReference("WebOriginDataManager");
}

class GetOrigins {
public:
    typedef std::tuple<uint32_t, uint64_t> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("GetOrigins"); }
    static const bool isSync = false;

    GetOrigins(uint32_t types, uint64_t callbackID)
        : m_arguments(types, callbackID)
    {
    }

    const std::tuple<uint32_t, uint64_t> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint32_t, uint64_t> m_arguments;
};

class DeleteEntriesForOrigin {
public:
    typedef std::tuple<uint32_t, WebKit::SecurityOriginData> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DeleteEntriesForOrigin"); }
    static const bool isSync = false;

    DeleteEntriesForOrigin(uint32_t types, const WebKit::SecurityOriginData& originIdentifier)
        : m_arguments(types, originIdentifier)
    {
    }

    const std::tuple<uint32_t, const WebKit::SecurityOriginData&> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint32_t, const WebKit::SecurityOriginData&> m_arguments;
};

class DeleteAllEntries {
public:
    typedef std::tuple<uint32_t> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DeleteAllEntries"); }
    static const bool isSync = false;

    explicit DeleteAllEntries(uint32_t types)
        : m_arguments(types)
    {
    }

    const std::tuple<uint32_t> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint32_t> m_arguments;
};

class StartObservingChanges {
public:
    typedef std::tuple<uint32_t> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("StartObservingChanges"); }
    static const bool isSync = false;

    explicit StartObservingChanges(uint32_t types)
        : m_arguments(types)
    {
    }

    const std::tuple<uint32_t> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint32_t> m_arguments;
};

class StopObservingChanges {
public:
    typedef std::tuple<uint32_t> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("StopObservingChanges"); }
    static const bool isSync = false;

    explicit StopObservingChanges(uint32_t types)
        : m_arguments(types)
    {
    }

    const std::tuple<uint32_t> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint32_t> m_arguments;
};

} // namespace WebOriginDataManager
} // namespace Messages

#endif // WebOriginDataManagerMessages_h
